searchData={"content_type":"text/markdown","items":[{"doc":"Minimal SMTP client.","ref":"Mua.html","title":"Mua","type":"module"},{"doc":"Sends `AUTH` extension command and authenticates the sender.\n\n    :ok = auth(socket, :login, username: username, password: password)\n    :ok = auth(socket, :plain, username: username, password: password)","ref":"Mua.html#auth/4","title":"Mua.auth/4","type":"function"},{"doc":"Closes connection to the SMTP server.\n\n    :ok = close(socket)","ref":"Mua.html#close/1","title":"Mua.close/1","type":"function"},{"doc":"Connects to an SMTP server and receives its banner.\n\n    {:ok, socket, _banner} = connect(:tcp, host, _port = 25)\n    {:ok, socket, _banner} = connect(:ssl, host, _port = 465, versions: [:\"tlsv1.3\"])","ref":"Mua.html#connect/5","title":"Mua.connect/5","type":"function"},{"doc":"Sends `DATA` command that specifies the beginning of the mail, and then sends the message.\n\n    {:ok, _receipt} = data(socket, \"Date: Sat, 24 Jun 2023 13:43:57 +0000\\r\\n...\")","ref":"Mua.html#data/3","title":"Mua.data/3","type":"function"},{"doc":"Utility function to send a message to a list of recipients on a host.\n\n    {:ok, _receipt} =\n      easy_send(\n        _host = \"gmail.com\",\n        _sender = \"hey@copycat.fun\",\n        _recipients = [\"dogaruslan@gmail.com\"],\n        _message = \"Date: Sat, 24 Jun 2023 13:43:57 +0000\\r\\n...\"\n      )","ref":"Mua.html#easy_send/5","title":"Mua.easy_send/5","type":"function"},{"doc":"Sends `EHLO` command which provides the identification of the sender i.e. the host name,\nand receives the list of extensions the server supports.\n\n    {:ok, _extensions = [\"STARTTLS\" | _rest]} = ehlo(socket, _our_hostname = \"copycat.fun\")","ref":"Mua.html#ehlo/3","title":"Mua.ehlo/3","type":"function"},{"doc":"Utility function to guess the local FQDN.\n\n    {:ok, \"mac3\"} = guess_fqdn()","ref":"Mua.html#guess_fqdn/0","title":"Mua.guess_fqdn/0","type":"function"},{"doc":"Sends `HELO` command which provides the identification of the sender i.e. the host name.\n\n    :ok = helo(socket, _our_hostname = \"copycat.fun\")","ref":"Mua.html#helo/3","title":"Mua.helo/3","type":"function"},{"doc":"Sends `MAIL FROM` command that specifies the originator of the mail.\n\n    :ok = mail_from(socket, \"hey@copycat.fun\")","ref":"Mua.html#mail_from/3","title":"Mua.mail_from/3","type":"function"},{"doc":"Utility function to lookup MX servers for a domain.\n\n    [\"gmail-smtp-in.l.google.com\" | _rest] = mxlookup(\"gmail.com\")","ref":"Mua.html#mxlookup/1","title":"Mua.mxlookup/1","type":"function"},{"doc":"Sends `NOOP` command that does nothing.\n\n    :ok = noop(socket)","ref":"Mua.html#noop/2","title":"Mua.noop/2","type":"function"},{"doc":"Utility function to pick a supported auth method from a list of extensions.\n\n    {:ok, extensions} = ehlo(socket, hostname)\n    maybe_method = pick_auth_method(extensions)\n    true = maybe_method in [nil, :plain, :login]","ref":"Mua.html#pick_auth_method/1","title":"Mua.pick_auth_method/1","type":"function"},{"doc":"Sends `QUIT` command that make the server close the connection.\n\n    :ok = quit(socket)","ref":"Mua.html#quit/2","title":"Mua.quit/2","type":"function"},{"doc":"Sends `RCPT TO` command that specify the recipient of the mail.\n\n    :ok = rcpt_to(socket, \"world@hey.com\")","ref":"Mua.html#rcpt_to/3","title":"Mua.rcpt_to/3","type":"function"},{"doc":"Sends `RSET` command that aborts the current mail transaction but keeps the socket open.\n\n    :ok = rset(socket)","ref":"Mua.html#rset/2","title":"Mua.rset/2","type":"function"},{"doc":"Sends `STARTTLS` extension command and starts TLS session negotiation.\n\n    {:ok, sslsocket} = starttls(socket, host, versions: [:\"tlsv1.3\"])","ref":"Mua.html#starttls/4","title":"Mua.starttls/4","type":"function"},{"doc":"Sends `VRFY` command that confirms or verifies the user name.\n\n    {:ok, true} = vrfy(socket, \"dogaruslan@gmail.com\")","ref":"Mua.html#vrfy/3","title":"Mua.vrfy/3","type":"function"},{"doc":"","ref":"Mua.html#t:auth_method/0","title":"Mua.auth_method/0","type":"type"},{"doc":"","ref":"Mua.html#t:error/0","title":"Mua.error/0","type":"type"},{"doc":"","ref":"Mua.html#t:host/0","title":"Mua.host/0","type":"type"},{"doc":"","ref":"Mua.html#t:proto/0","title":"Mua.proto/0","type":"type"},{"doc":"","ref":"Mua.html#t:socket/0","title":"Mua.socket/0","type":"type"},{"doc":"An SMTP error.\n\nContains the following fields:\n\n  - `:code` - [SMTP error code](https://en.wikipedia.org/wiki/List_of_SMTP_server_return_codes)\n  - `:lines` - lines received from the server","ref":"Mua.SMTPError.html","title":"Mua.SMTPError","type":"exception"},{"doc":"","ref":"Mua.SMTPError.html#message/1","title":"Mua.SMTPError.message/1","type":"function"},{"doc":"","ref":"Mua.SMTPError.html#t:t/0","title":"Mua.SMTPError.t/0","type":"type"},{"doc":"Represents an error with the transport used by an SMTP connection.\n\nContains the following fields:\n\n  - `:reason` - a term representing the error reason. The value of this field\n    can be:\n\n      - `:timeout` - if there's a timeout in interacting with the socket.\n\n      - `:closed` - if the connection has been closed.\n\n      - `t::inet.posix/0` - if there's any other error with the socket,\n        such as `:econnrefused` or `:nxdomain`.\n\n      - `t::ssl.error_alert/0` - if there's an SSL error.","ref":"Mua.TransportError.html","title":"Mua.TransportError","type":"exception"},{"doc":"","ref":"Mua.TransportError.html#message/1","title":"Mua.TransportError.message/1","type":"function"},{"doc":"","ref":"Mua.TransportError.html#t:t/0","title":"Mua.TransportError.t/0","type":"type"},{"doc":"# Mua\n\n[![Hex Package](https://img.shields.io/hexpm/v/mua.svg)](https://hex.pm/packages/mua)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/mua)\n\nMinimal SMTP client (aka Mail user agent).\n\nCan be used with [Bamboo](https://github.com/ruslandoga/bamboo_mua) and [Swoosh.](https://github.com/ruslandoga/swoosh_mua)\n\n#","ref":"readme.html","title":"Mua","type":"extras"},{"doc":"- Direct messaging (no relays)\n- Minimal API\n\nYour ideas are welcome [here.](https://github.com/ruslandoga/mua/issues/2)","ref":"readme.html#features","title":"Features - Mua","type":"extras"},{"doc":"```elixir\ndefp deps do\n  [\n    {:mua, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Mua","type":"extras"},{"doc":"Single command high-level API:\n\n```elixir\n# MAIL FROM:\nfrom = \"hey@copycat.fun\"\n\n# RCPT TO:\nrecipients = [\n  \"dogaruslan@gmail.com\",\n  \"ruslan.doga@ya.ru\"\n]\n\n# check out these packages for message encoding:\n# - https://hex.pm/packages/mail\n# - https://hex.pm/packages/mailibex\nmessage = \"\"\"\nDate: Sat, 24 Jun 2023 13:43:57 +0000\\r\nFrom: Ruslan  \\r\nSubject: README\\r\nTo: Ruslan  \\r\nCC: Ruslan  \\r\n\\r\nlike and subscribe\\r\n.\\r\n\"\"\"\n\nhost = fn recipient ->\n  [_user, host] = String.split(recipient, \"@\")\n  host\nend\n\nrecipients\n|> Enum.group_by(host)\n|> Enum.map(fn {host, recipients} ->\n  {host, Mua.easy_send(host, from, recipients, message)}\nend)\n```\n\nLow-level API:\n\n```elixir\n[host | _rest] = Mua.mxlookup(\"gmail.com\")\n{:ok, socket, _banner} = Mua.connect(:tcp, host, _port = 25)\n\n{:ok, our_hostname} = Mua.guess_fqdn()\n{:ok, extensions} = Mua.ehlo(socket, our_hostname)\n\ntrue = \"STARTTLS\" in extensions\n{:ok, socket} = Mua.starttls(socket, host)\n\n:ok = Mua.mail_from(socket, \"hey@copycat.fun\")\n:ok = Mua.rcpt_to(socket, \"dogaruslan@gmail.com\")\n\n{:ok, _receipt} =\n  Mua.data(socket, \"\"\"\n  Date: Sat, 24 Jun 2023 13:43:57 +0000\\r\n  From: Ruslan  \\r\n  Subject: How was your day?\\r\n  To: Ruslan  \\r\n  \\r\n  Mine was fine.\\r\n  .\\r\n  \"\"\")\n\n:ok = Mua.quit(socket)\n:ok = Mua.close(socket)\n```","ref":"readme.html#usage","title":"Usage - Mua","type":"extras"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"","ref":"changelog.html#unreleased","title":"Unreleased - Changelog","type":"extras"},{"doc":"- add `Mua.TransportError` like in [Mint](https://github.com/elixir-mint/mint/blob/main/lib/mint/transport_error.ex) https://github.com/ruslandoga/mua/pull/6","ref":"changelog.html#v0-1-3-2023-07-14","title":"v0.1.3 (2023-07-14) - Changelog","type":"extras"},{"doc":"- refactor `AUTH` https://github.com/ruslandoga/mua/pull/5","ref":"changelog.html#v0-1-2-2023-07-14","title":"v0.1.2 (2023-07-14) - Changelog","type":"extras"},{"doc":"- add `AUTH` https://github.com/ruslandoga/mua/pull/4","ref":"changelog.html#v0-1-1-2023-07-14","title":"v0.1.1 (2023-07-14) - Changelog","type":"extras"}]}